This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] cp: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-09-21  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: Follow spelling conventions.
	* ChangeLog.2: Likewise.
	* call.c: Likewise.
	* class.c: Likewise.
	* cp-tree.h: Likewise.
	* cvt.c: Likewise.
	* decl.c: Likewise.
	* decl2.c: Likewise.
	* except.c: Likewise.
	* friend.c: Likewise.
	* g++spec.c: Likewise.
	* init.c: Likewise.
	* lex.c: Likewise.
	* mangle.c: Likewise.
	* method.c: Likewise.
	* operators.def: Likewise.
	* optimize.c: Likewise.
	* pt.c: Likewise.
	* rtti.c: Likewise.
	* search.c: Likewise.
	* semantics.c: Likewise.
	* spew.c: Likewise.
	* tree.c: Likewise.
	* typeck.c: Likewise.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog,v
retrieving revision 1.2965
diff -u -r1.2965 ChangeLog
--- ChangeLog	18 Sep 2002 13:08:29 -0000	1.2965
+++ ChangeLog	21 Sep 2002 12:42:22 -0000
@@ -4261,7 +4261,7 @@
 
 	PR c++/3621
 	* spew.c (yylex): Only copy the token's lineno, if it is
-	non-zero.
+	nonzero.
 
 2001-07-26  Nathan Sidwell  <nathan@codesourcery.com>
 
@@ -4399,7 +4399,7 @@
 2001-07-20  Nathan Sidwell  <nathan@codesourcery.com>
 
 	Remove old-abi remnants. Remove comments about old abi
-	behaviour. Remove references to 'new-abi' in comments.
+	behavior. Remove references to 'new-abi' in comments.
 	* cp-tree.h: Adjust comments.
 	(vbase_offsets_in_vtable_p): Delete.
 	(vcall_offsets_in_vtable_p): Delete.
@@ -5601,7 +5601,7 @@
 	(maybe_commonize_var): Allow inlining functions even if they have
 	static local variables, use comdat_linkage for them if flag_weak.
 	(check_initializer): Call obscure_complex_init if
-	grok_reference_init returned non-zero.
+	grok_reference_init returned nonzero.
 	(save_function_data): Clear x_local_names.
 	(pop_cp_function_context): Free x_local_names.
 	(mark_inlined_fns): Remove.
@@ -12748,7 +12748,7 @@
 	(add_method): Used functions are hidden by local functions.
 	(check_bases_and_members): Handle using-decls before finalizing
 	CLASSTYPE_METHOD_VEC.
-	* call.c (add_function_candidate): Add ctype parm; if non-zero,
+	* call.c (add_function_candidate): Add ctype parm; if nonzero,
 	override the type of 'this' accordingly.
 	(add_template_candidate, add_template_candidate_real): Add ctype parm.
 	(convert_class_to_reference, build_user_type_conversion_1,
Index: ChangeLog.2
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/ChangeLog.2,v
retrieving revision 1.3
diff -u -r1.3 ChangeLog.2
--- ChangeLog.2	16 Dec 2001 16:06:57 -0000	1.3
+++ ChangeLog.2	21 Sep 2002 12:42:44 -0000
@@ -1264,7 +1264,7 @@
 
 1999-10-06  Brendan Kehoe  <brendan@cygnus.com>
 
-	* decl.c (grokdeclarator): Only warn about non-zero arrays if
+	* decl.c (grokdeclarator): Only warn about nonzero arrays if
 	!in_system_header (linux socketbits.h can give this for
 	__cmsg_data, which is using a GNU extension).
 
@@ -19205,7 +19205,7 @@
 
 	* sig.c (build_signature_pointer_or_reference_type): Align
 	signature pointers/references on 8-byte boundaries so they can be
-	grabbed 2 words at a time on a Sparc.
+	grabbed 2 words at a time on a SPARC.
 
 Tue Mar  5 10:21:01 1996  Jason Merrill  <jason@yorick.cygnus.com>
 
Index: cp-tree.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/cp-tree.h,v
retrieving revision 1.750
diff -u -r1.750 cp-tree.h
--- cp-tree.h	19 Sep 2002 16:19:35 -0000	1.750
+++ cp-tree.h	21 Sep 2002 12:43:01 -0000
@@ -318,11 +318,11 @@
 #define same_type_ignoring_top_level_qualifiers_p(TYPE1, TYPE2) \
   same_type_p (TYPE_MAIN_VARIANT (TYPE1), TYPE_MAIN_VARIANT (TYPE2))
 
-/* Non-zero if we are presently building a statement tree, rather
+/* Nonzero if we are presently building a statement tree, rather
    than expanding each statement as we encounter it.  */
 #define building_stmt_tree() (last_tree != NULL_TREE)
 
-/* Returns non-zero iff NODE is a declaration for the global function
+/* Returns nonzero iff NODE is a declaration for the global function
    `main'.  */
 #define DECL_MAIN_P(NODE)				\
    (DECL_EXTERN_C_FUNCTION_P (NODE)                     \
@@ -901,13 +901,13 @@
 #define current_function_returns_abnormally \
   cp_function_chain->returns_abnormally
 
-/* Non-zero if we should generate RTL for functions that we process.
+/* Nonzero if we should generate RTL for functions that we process.
    When this is zero, we just accumulate tree structure, without
    interacting with the back end.  */
 
 #define expanding_p cp_function_chain->x_expanding_p
 
-/* Non-zero if we are in the semantic analysis phase for the current
+/* Nonzero if we are in the semantic analysis phase for the current
    function.  */
 
 #define doing_semantic_analysis_p() (!expanding_p)
@@ -1789,7 +1789,7 @@
        && TREE_SYMBOL_REFERENCED (DECL_ASSEMBLER_NAME (DECL)))	\
    || (flag_syntax_only && TREE_USED (DECL)))
 
-/* Non-zero iff DECL is memory-based.  The DECL_RTL of
+/* Nonzero iff DECL is memory-based.  The DECL_RTL of
    certain const variables might be a CONST_INT, or a REG
    in some cases.  We cannot use `memory_operand' as a test
    here because on most RISC machines, a variable's address
@@ -1891,22 +1891,22 @@
 /* Discriminator for name mangling.  */
 #define DECL_DISCRIMINATOR(NODE) (LANG_DECL_U2_CHECK (NODE, 1)->discriminator)
 
-/* Non-zero if the VTT parm has been added to NODE.  */
+/* Nonzero if the VTT parm has been added to NODE.  */
 #define DECL_HAS_VTT_PARM_P(NODE) \
   (DECL_LANG_SPECIFIC (NODE)->decl_flags.has_vtt_parm_p)
 
-/* Non-zero if NODE is a FUNCTION_DECL for which a VTT parameter is
+/* Nonzero if NODE is a FUNCTION_DECL for which a VTT parameter is
    required.  */
 #define DECL_NEEDS_VTT_PARM_P(NODE)			\
   (TYPE_USES_VIRTUAL_BASECLASSES (DECL_CONTEXT (NODE))	\
    && (DECL_BASE_CONSTRUCTOR_P (NODE)			\
        || DECL_BASE_DESTRUCTOR_P (NODE)))
 
-/* Non-zero if NODE is a user-defined conversion operator.  */
+/* Nonzero if NODE is a user-defined conversion operator.  */
 #define DECL_CONV_FN_P(NODE) \
   (IDENTIFIER_TYPENAME_P (DECL_NAME (NODE)))
 
-/* Non-zero if NODE, which is a TEMPLATE_DECL, is a template
+/* Nonzero if NODE, which is a TEMPLATE_DECL, is a template
    conversion operator to a type dependent on the innermost template
    args.  */
 #define DECL_TEMPLATE_CONV_FN_P(NODE) \
@@ -1927,7 +1927,7 @@
   (IDENTIFIER_OPNAME_P (DECL_NAME (NODE))		\
    ? DECL_LANG_SPECIFIC (NODE)->u.f.operator_code : ERROR_MARK)
 
-/* Non-zero if NODE is an assignment operator.  */
+/* Nonzero if NODE is an assignment operator.  */
 #define DECL_ASSIGNMENT_OPERATOR_P(NODE) \
   (DECL_LANG_SPECIFIC (NODE)->decl_flags.assignment_operator_p)
 
@@ -2107,7 +2107,7 @@
 #define ORIGINAL_NAMESPACE(NODE)  \
   (DECL_NAMESPACE_ALIAS (NODE) ? DECL_NAMESPACE_ALIAS (NODE) : (NODE))
 
-/* Non-zero if NODE is the std namespace.  */
+/* Nonzero if NODE is the std namespace.  */
 #define DECL_NAMESPACE_STD_P(NODE)			\
   (TREE_CODE (NODE) == NAMESPACE_DECL			\
    && CP_DECL_CONTEXT (NODE) == global_namespace	\
@@ -2200,7 +2200,7 @@
    only one level of arguments, but which is a TREE_VEC containing as
    its only entry the TREE_VEC for that level.  */
 
-/* Non-zero if the template arguments is actually a vector of vectors,
+/* Nonzero if the template arguments is actually a vector of vectors,
    rather than just a vector.  */
 #define TMPL_ARGS_HAVE_MULTIPLE_LEVELS(NODE) \
   ((NODE) != NULL_TREE						\
@@ -2383,7 +2383,7 @@
 /* Record whether a typedef for type `int' was actually `signed int'.  */
 #define C_TYPEDEF_EXPLICITLY_SIGNED(EXP) DECL_LANG_FLAG_1 (EXP)
 
-/* Returns non-zero if DECL has external linkage, as specified by the
+/* Returns nonzero if DECL has external linkage, as specified by the
    language standard.  (This predicate may hold even when the
    corresponding entity is not actually given external linkage in the
    object file; see decl_linkage for details.)  */
@@ -2801,7 +2801,7 @@
 #define DECL_PRIMARY_TEMPLATE(NODE) \
   (TREE_TYPE (DECL_INNERMOST_TEMPLATE_PARMS (NODE)))
 
-/* Returns non-zero if NODE is a primary template.  */
+/* Returns nonzero if NODE is a primary template.  */
 #define PRIMARY_TEMPLATE_P(NODE) (DECL_PRIMARY_TEMPLATE (NODE) == (NODE))
 
 #define CLASSTYPE_TEMPLATE_LEVEL(NODE) \
@@ -2840,7 +2840,7 @@
 #define SET_CLASSTYPE_EXPLICIT_INSTANTIATION(NODE) \
   (CLASSTYPE_USE_TEMPLATE (NODE) = 3)
 
-/* Non-zero if DECL is a friend function which is an instantiation
+/* Nonzero if DECL is a friend function which is an instantiation
    from the point of view of the compiler, but not from the point of
    view of the language.  For example given:
       template <class T> struct S { friend void f(T) {}; };
@@ -2850,13 +2850,13 @@
 #define DECL_FRIEND_PSEUDO_TEMPLATE_INSTANTIATION(DECL) \
   (DECL_TEMPLATE_INFO (DECL) && !DECL_USE_TEMPLATE (DECL))
 
-/* Non-zero if TYPE is a partial instantiation of a template class,
+/* Nonzero if TYPE is a partial instantiation of a template class,
    i.e., an instantiation whose instantiation arguments involve
    template types.  */
 #define PARTIAL_INSTANTIATION_P(TYPE) \
   (LANG_TYPE_CLASS_CHECK (TYPE)->is_partial_instantiation)
 
-/* Non-zero iff we are currently processing a declaration for an
+/* Nonzero iff we are currently processing a declaration for an
    entity with its own template parameter list, and which is not a
    full specialization.  */
 #define PROCESSING_REAL_TEMPLATE_DECL_P() \
@@ -3249,7 +3249,7 @@
 				  && IDENTIFIER_POINTER (ID_NODE)[1] == '_')
 #endif /* !defined(NO_DOLLAR_IN_LABEL) || !defined(NO_DOT_IN_LABEL) */
 
-/* Returns non-zero iff NODE is a declaration for the global function
+/* Returns nonzero iff NODE is a declaration for the global function
    `main'.  */
 #define DECL_MAIN_P(NODE)				\
    (DECL_EXTERN_C_FUNCTION_P (NODE)                     \
Index: cvt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/cvt.c,v
retrieving revision 1.123
diff -u -r1.123 cvt.c
--- cvt.c	13 Sep 2002 00:22:59 -0000	1.123
+++ cvt.c	21 Sep 2002 12:43:02 -0000
@@ -1014,7 +1014,7 @@
    allowed (references private members, etc).
    If no conversion exists, NULL_TREE is returned.
 
-   If (FOR_SURE & 1) is non-zero, then we allow this type conversion
+   If (FOR_SURE & 1) is nonzero, then we allow this type conversion
    to take place immediately.  Otherwise, we build a SAVE_EXPR
    which can be evaluated if the results are ever needed.
 
Index: except.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/except.c,v
retrieving revision 1.145
diff -u -r1.145 except.c
--- except.c	14 Sep 2002 12:07:42 -0000	1.145
+++ except.c	21 Sep 2002 12:43:19 -0000
@@ -796,7 +796,7 @@
 
 /* Make sure TYPE is complete, pointer to complete, reference to
    complete, or pointer to cv void. Issue diagnostic on failure.
-   Return the zero on failure and non-zero on success. FROM can be
+   Return the zero on failure and nonzero on success. FROM can be
    the expr or decl from whence TYPE came, if available.  */
 
 static int
Index: friend.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/friend.c,v
retrieving revision 1.75
diff -u -r1.75 friend.c
--- friend.c	14 Sep 2002 12:07:42 -0000	1.75
+++ friend.c	21 Sep 2002 12:43:20 -0000
@@ -30,7 +30,7 @@
 
 /* Friend data structures are described in cp-tree.h.  */
 
-/* Returns non-zero if SUPPLICANT is a friend of TYPE.  */
+/* Returns nonzero if SUPPLICANT is a friend of TYPE.  */
 
 int
 is_friend (type, supplicant)
Index: g++spec.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/g++spec.c,v
retrieving revision 1.29
diff -u -r1.29 g++spec.c
--- g++spec.c	14 Sep 2002 12:07:42 -0000	1.29
+++ g++spec.c	21 Sep 2002 12:43:20 -0000
@@ -51,10 +51,10 @@
 {
   int i, j;
 
-  /* If non-zero, the user gave us the `-p' or `-pg' flag.  */ 
+  /* If nonzero, the user gave us the `-p' or `-pg' flag.  */
   int saw_profile_flag = 0;
 
-  /* If non-zero, the user gave us the `-v' flag.  */ 
+  /* If nonzero, the user gave us the `-v' flag.  */
   int saw_verbose_flag = 0;
 
   /* This will be 0 if we encounter a situation where we should not
@@ -73,7 +73,7 @@
   /* The new argument list will be contained in this.  */
   const char **arglist;
 
-  /* Non-zero if we saw a `-xfoo' language specification on the
+  /* Nonzero if we saw a `-xfoo' language specification on the
      command line.  Used to avoid adding our own -xc++ if the user
      already gave a language for the file.  */
   int saw_speclang = 0;
Index: init.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/init.c,v
retrieving revision 1.291
diff -u -r1.291 init.c
--- init.c	14 Sep 2002 12:07:43 -0000	1.291
+++ init.c	21 Sep 2002 12:43:23 -0000
@@ -840,7 +840,7 @@
 /* If an exception is thrown in a constructor, those base classes already
    constructed must be destroyed.  This function creates the cleanup
    for BINFO, which has just been constructed.  If FLAG is non-NULL,
-   it is a DECL which is non-zero when this base needs to be
+   it is a DECL which is nonzero when this base needs to be
    destroyed.  */
 
 static void
@@ -886,7 +886,7 @@
 
 /* Construct the virtual base-classes of THIS_REF (whose address is
    THIS_PTR).  The object has the indicated TYPE.  The construction
-   actually takes place only if FLAG is non-zero.  INIT_LIST is list
+   actually takes place only if FLAG is nonzero.  INIT_LIST is list
    of initializations for constructors to perform.  */
 
 static void
Index: lex.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/lex.c,v
retrieving revision 1.290
diff -u -r1.290 lex.c
--- lex.c	14 Sep 2002 12:07:43 -0000	1.290
+++ lex.c	21 Sep 2002 12:43:24 -0000
@@ -540,7 +540,7 @@
   /* RID_REINTCAST */	REINTERPRET_CAST,
   /* RID_STATCAST */	STATIC_CAST,
 
-  /* Objective C */
+  /* Objective-C */
   /* RID_ID */			0,
   /* RID_AT_ENCODE */		0,
   /* RID_AT_END */		0,
Index: method.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/method.c,v
retrieving revision 1.229
diff -u -r1.229 method.c
--- method.c	14 Sep 2002 12:07:43 -0000	1.229
+++ method.c	21 Sep 2002 12:43:27 -0000
@@ -350,7 +350,7 @@
 }
 
 /* Emit the definition of a C++ multiple inheritance vtable thunk.  If
-   EMIT_P is non-zero, the thunk is emitted immediately.  */
+   EMIT_P is nonzero, the thunk is emitted immediately.  */
 
 void
 use_thunk (thunk_fndecl, emit_p)
Index: operators.def
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/operators.def,v
retrieving revision 1.10
diff -u -r1.10 operators.def
--- operators.def	2 Jul 2002 03:19:22 -0000	1.10
+++ operators.def	21 Sep 2002 12:43:27 -0000
@@ -54,7 +54,7 @@
 
    ASSN_P
 
-     A boolean value.  If non-zero, this is an assignment operator.  
+     A boolean value.  If nonzero, this is an assignment operator.
 
    Before including this file, you should define DEFOPERATOR
    to take these arguments.  
Index: spew.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/spew.c,v
retrieving revision 1.72
diff -u -r1.72 spew.c
--- spew.c	14 Sep 2002 12:07:44 -0000	1.72
+++ spew.c	21 Sep 2002 12:43:43 -0000
@@ -832,7 +832,7 @@
 }
 
 /* Unget character CH from the input stream.
-   If RESCAN is non-zero, then we want to `see' this
+   If RESCAN is nonzero, then we want to `see' this
    character as the next input token.  */
 
 void
Index: call.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/call.c,v
retrieving revision 1.334
diff -u -r1.334 call.c
--- call.c	15 Sep 2002 18:16:10 -0000	1.334
+++ call.c	21 Sep 2002 12:42:49 -0000
@@ -647,7 +647,7 @@
 }
 
 
 /* Returns non-zero if PARMLIST consists of only default parms and/or
    ellipsis.  */
 
 int
@@ -938,7 +938,7 @@
   return conv;
 }
 
 /* Returns non-zero if T1 is reference-related to T2.  */
 
 static int
 reference_related_p (t1, t2)
@@ -958,7 +958,7 @@
 	      && DERIVED_FROM_P (t1, t2)));
 }
 
 /* Returns non-zero if T1 is reference-compatible with T2.  */
 
 static int
 reference_compatible_p (t1, t2)
@@ -1623,7 +1623,7 @@
   return COMPLETE_TYPE_P (complete_type (t));
 }
 
 /* Returns non-zero if TYPE is a promoted arithmetic type.  */
 
 static int
 promoted_arithmetic_type_p (type)
@@ -3874,7 +3874,7 @@
 
 /* Perform the conversions in CONVS on the expression EXPR. 
    FN and ARGNUM are used for diagnostics.  ARGNUM is zero based, -1
-   indicates the `this' argument of a method.  INNER is non-zero when
+   indicates the `this' argument of a method.  INNER is nonzero when
    being called to continue a conversion chain. It is negative when a
    reference binding will be applied, positive otherwise.  */
 
@@ -4118,7 +4118,7 @@
   
   if (arg != error_mark_node && ! pod_type_p (TREE_TYPE (arg)))
     {
-      /* Undefined behaviour [expr.call] 5.2.2/7.  We used to just warn
+      /* Undefined behavior [expr.call] 5.2.2/7.  We used to just warn
 	 here and do a bitwise copy, but now cp_expr_size will abort if we
 	 try to do that.  */
       error ("cannot pass objects of non-POD type `%#T' through `...'",
@@ -4146,7 +4146,7 @@
   
   if (! pod_type_p (type))
     {
-      /* Undefined behaviour [expr.call] 5.2.2/7.  */
+      /* Undefined behavior [expr.call] 5.2.2/7.  */
       warning ("cannot receive objects of non-POD type `%#T' through `...'",
 		  type);
     }
@@ -4906,7 +4906,7 @@
   return call;
 }
 
 /* Returns non-zero iff standard conversion sequence ICS1 is a proper
    subsequence of ICS2.  */
 
 static int
@@ -4946,7 +4946,7 @@
     }
 }
 
 /* Returns non-zero iff DERIVED is derived from BASE.  The inputs may
    be any _TYPE nodes.  */
 
 int
@@ -5044,7 +5044,7 @@
   tree deref_to_type2 = NULL_TREE;
   int rank1, rank2;
 
   /* REF_BINDING is non-zero if the result of the conversion sequence
      is a reference type.   In that case TARGET_TYPE is the
      type referred to by the reference.  */
   tree target_type1;
@@ -5743,7 +5743,7 @@
   return champ;
 }
 
 /* Returns non-zero if things of type FROM can be converted to TO.  */
 
 int
 can_convert (to, from)
@@ -5752,7 +5752,7 @@
   return can_convert_arg (to, from, NULL_TREE);
 }
 
 /* Returns non-zero if ARG (of type FROM) can be converted to TO.  */
 
 int
 can_convert_arg (to, from, arg)
@@ -647,7 +647,7 @@
 
 
-/* Returns non-zero if PARMLIST consists of only default parms and/or
+/* Returns nonzero if PARMLIST consists of only default parms and/or
    ellipsis.  */
 
@@ -938,7 +938,7 @@
 }
 
-/* Returns non-zero if T1 is reference-related to T2.  */
+/* Returns nonzero if T1 is reference-related to T2.  */
 
 static int
@@ -958,7 +958,7 @@
 }
 
-/* Returns non-zero if T1 is reference-compatible with T2.  */
+/* Returns nonzero if T1 is reference-compatible with T2.  */
 
 static int
@@ -1623,7 +1623,7 @@
 }
 
-/* Returns non-zero if TYPE is a promoted arithmetic type.  */
+/* Returns nonzero if TYPE is a promoted arithmetic type.  */
 
 static int
@@ -4906,7 +4906,7 @@
 }
 
-/* Returns non-zero iff standard conversion sequence ICS1 is a proper
+/* Returns nonzero iff standard conversion sequence ICS1 is a proper
    subsequence of ICS2.  */
 
@@ -4946,7 +4946,7 @@
 }
 
-/* Returns non-zero iff DERIVED is derived from BASE.  The inputs may
+/* Returns nonzero iff DERIVED is derived from BASE.  The inputs may
    be any _TYPE nodes.  */
 
@@ -5044,7 +5044,7 @@
   int rank1, rank2;
 
-  /* REF_BINDING is non-zero if the result of the conversion sequence
+  /* REF_BINDING is nonzero if the result of the conversion sequence
      is a reference type.   In that case TARGET_TYPE is the
      type referred to by the reference.  */
@@ -5743,7 +5743,7 @@
 }
 
-/* Returns non-zero if things of type FROM can be converted to TO.  */
+/* Returns nonzero if things of type FROM can be converted to TO.  */
 
 int
@@ -5752,7 +5752,7 @@
 }
 
-/* Returns non-zero if ARG (of type FROM) can be converted to TO.  */
+/* Returns nonzero if ARG (of type FROM) can be converted to TO.  */
 
 int
Index: class.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/class.c,v
retrieving revision 1.466
diff -u -r1.466 class.c
--- class.c	13 Sep 2002 00:22:58 -0000	1.466
+++ class.c	21 Sep 2002 12:42:56 -0000
@@ -532,7 +532,7 @@
 
 /* Get the VAR_DECL of the vtable for TYPE. TYPE need not be polymorphic,
    or even complete.  If this does not exist, create it.  If COMPLETE is
-   non-zero, then complete the definition of it -- that will render it
+   nonzero, then complete the definition of it -- that will render it
    impossible to actually build the vtable, but is useful to get at those
    which are known to exist in the runtime.  */
 
@@ -593,7 +593,7 @@
 /* Build the primary virtual function table for TYPE.  If BINFO is
    non-NULL, build the vtable starting with the initial approximation
    that it is the same as the one which is the head of the association
-   list.  Returns a non-zero value if a new vtable is actually
+   list.  Returns a nonzero value if a new vtable is actually
    created.  */
 
 static int
@@ -645,7 +645,7 @@
    FOR_TYPE is the most derived type which caused this table to
    be needed.
 
-   Returns non-zero if we haven't met BINFO before.
+   Returns nonzero if we haven't met BINFO before.
 
    The order in which vtables are built (by calling this function) for
    an object must remain the same, otherwise a binary incompatibility
@@ -676,7 +676,7 @@
 }
 
 /* Create a new vtable for BINFO which is the hierarchy dominated by
-   T. Return non-zero if we actually created a new vtable.  */
+   T. Return nonzero if we actually created a new vtable.  */
 
 static int
 make_new_vtable (t, binfo)
@@ -2158,7 +2158,7 @@
       layout_decl (vtable, 0);
 
       /* At one time the vtable info was grabbed 2 words at a time.  This
-	 fails on Sparc unless you have 8-byte alignment.  */
+	 fails on SPARC unless you have 8-byte alignment.  */
       DECL_ALIGN (vtable) = MAX (TYPE_ALIGN (double_type_node),
 				 DECL_ALIGN (vtable));
     }
@@ -2645,7 +2645,7 @@
 /* Here, we already know that they match in every respect.
    All we have to check is where they had their declarations.
 
-   Return non-zero iff FNDECL1 is declared in a class which has a
+   Return nonzero iff FNDECL1 is declared in a class which has a
    proper base class containing FNDECL2.  We don't care about
    ambiguity or accessibility.  */
 
@@ -3454,7 +3454,7 @@
   return 0;
 }
 
 /* Returns non-zero if TYPE is an empty class type and there is
    already an entry in OFFSETS for the same TYPE as the same OFFSET.  */
 
 static int
@@ -3483,13 +3483,13 @@
 
 /* Walk through all the subobjects of TYPE (located at OFFSET).  Call
    F for every subobject, passing it the type, offset, and table of
-   OFFSETS.  If VBASES_P is non-zero, then even virtual non-primary
+   OFFSETS.  If VBASES_P is nonzero, then even virtual non-primary
    bases should be traversed; otherwise, they are ignored.  
 
    If MAX_OFFSET is non-NULL, then subobjects with an offset greater
    than MAX_OFFSET will not be walked.
 
-   If F returns a non-zero value, the traversal ceases, and that value
+   If F returns a nonzero value, the traversal ceases, and that value
    is returned.  Otherwise, returns zero.  */
 
 static int
@@ -3588,7 +3588,7 @@
 }
 
 /* Record all of the empty subobjects of TYPE (located at OFFSET) in
-   OFFSETS.  If VBASES_P is non-zero, virtual bases of TYPE are
+   OFFSETS.  If VBASES_P is nonzero, virtual bases of TYPE are
    examined.  */
 
 static void
@@ -3602,8 +3602,8 @@
 			  offsets, /*max_offset=*/NULL_TREE, vbases_p);
 }
 
-/* Returns non-zero if any of the empty subobjects of TYPE (located at
-   OFFSET) conflict with entries in OFFSETS.  If VBASES_P is non-zero,
+/* Returns nonzero if any of the empty subobjects of TYPE (located at
+   OFFSET) conflict with entries in OFFSETS.  If VBASES_P is nonzero,
    virtual bases of TYPE are examined.  */
 
 static int
@@ -3671,7 +3671,7 @@
 	 offset zero -- its S component would be at the same address
 	 as the S we already allocated.  So, we have to skip ahead.
 	 Since all data members, including those whose type is an
-	 empty class, have non-zero size, any overlap can happen only
+	 empty class, have nonzero size, any overlap can happen only
 	 with a direct or indirect base-class -- it can't happen with
 	 a data member.  */
       if (layout_conflict_p (TREE_TYPE (decl),
@@ -3708,7 +3708,7 @@
    past the end of the class, and should be correctly aligned for a
    class of the type indicated by BINFO; OFFSETS gives the offsets of
    the empty bases allocated so far. T is the most derived
-   type.  Return non-zero iff we added it at the end.  */
+   type.  Return nonzero iff we added it at the end.  */
 
 static bool
 layout_empty_base (binfo, eoc, offsets, t)
@@ -3756,7 +3756,7 @@
    indicated by RLI.  If the new object is non-empty, clear *EMPTY_P.
    *BASE_ALIGN is a running maximum of the alignments of any base
    class.  OFFSETS gives the location of empty base subobjects.  T is
-   the most derived type.  Return non-zero if the new object cannot be
+   the most derived type.  Return nonzero if the new object cannot be
    nearly-empty.  */
 
 static bool
@@ -3818,7 +3818,7 @@
 
 /* Layout all of the non-virtual base classes.  Record empty
    subobjects in OFFSETS.  T is the most derived type.  Return
-   non-zero if the type cannot be nearly empty.  */
+   nonzero if the type cannot be nearly empty.  */
 
 static bool
 build_base_fields (rli, empty_p, offsets, t)
@@ -4018,7 +4018,7 @@
 }
 
 /* Produce declarations for all appropriate clones of FN.  If
-   UPDATE_METHOD_VEC_P is non-zero, the clones are added to the
+   UPDATE_METHOD_VEC_P is nonzero, the clones are added to the
    CLASTYPE_METHOD_VEC as well.  */
 
 void
@@ -4934,7 +4934,7 @@
     }
 
   /* We make all structures have at least one element, so that they
-     have non-zero size.  The class may be empty even if it has
+     have nonzero size.  The class may be empty even if it has
      basetypes.  Therefore, we add the fake field after all the other
      fields; if there are already FIELD_DECLs on the list, their
      offsets will not be disturbed.  */
@@ -5400,7 +5400,7 @@
     }
 }
 
 /* Return non-zero if the dynamic type of INSTANCE is known, and
    equivalent to the static type.  We also handle the case where
    INSTANCE is really a pointer. Return negative if this is a
    ctor/dtor. There the dynamic type is known, but this might not be
@@ -5746,7 +5746,7 @@
 /* Given an OVERLOAD and a TARGET_TYPE, return the function that
    matches the TARGET_TYPE.  If there is no satisfactory match, return
    error_mark_node, and issue an error message if COMPLAIN is
-   non-zero.  Permit pointers to member function if PTRMEM is non-zero.
+   nonzero.  Permit pointers to member function if PTRMEM is nonzero.
    If TEMPLATE_ONLY, the name of the overloaded function
    was a template-id, and EXPLICIT_TARGS are the explicitly provided
    template arguments.  */
@@ -6587,7 +6587,7 @@
   return result;
 }
 
 /* If INDENTED_P is zero, indent to INDENT. Return non-zero.  */
 
 static int
 maybe_indent_hierarchy (stream, indent, indented_p)
@@ -3454,7 +3454,7 @@
 }
 
-/* Returns non-zero if TYPE is an empty class type and there is
+/* Returns nonzero if TYPE is an empty class type and there is
    already an entry in OFFSETS for the same TYPE as the same OFFSET.  */
 
@@ -5400,7 +5400,7 @@
 }
 
-/* Return non-zero if the dynamic type of INSTANCE is known, and
+/* Return nonzero if the dynamic type of INSTANCE is known, and
    equivalent to the static type.  We also handle the case where
    INSTANCE is really a pointer. Return negative if this is a
@@ -6587,7 +6587,7 @@
 }
 
-/* If INDENTED_P is zero, indent to INDENT. Return non-zero.  */
+/* If INDENTED_P is zero, indent to INDENT. Return nonzero.  */
 
 static int
Index: decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/decl.c,v
retrieving revision 1.935
diff -u -r1.935 decl.c
--- decl.c	19 Sep 2002 16:19:36 -0000	1.935
+++ decl.c	21 Sep 2002 12:43:15 -0000
@@ -659,7 +659,7 @@
   return b->namespace_p;
 }
 
 /* If KEEP is non-zero, make a BLOCK node for the next binding level,
    unconditionally.  Otherwise, use the normal logic to decide whether
    or not to create a BLOCK.  */
 
@@ -688,7 +688,7 @@
   current_binding_level->namespace_p = 1;
 }
 
 /* Returns non-zero if this scope was created to store template
    parameters.  */
 
 int
@@ -1740,7 +1740,7 @@
     IDENTIFIER_CLASS_VALUE (TREE_PURPOSE (t)) = NULL_TREE;
 }
 
 /* Returns non-zero if T is a virtual function table.  */
 
 int
 vtable_decl_p (t, data)
@@ -1750,7 +1750,7 @@
   return (TREE_CODE (t) == VAR_DECL && DECL_VIRTUAL_P (t));
 }
 
 /* Returns non-zero if T is a TYPE_DECL for a type with virtual
    functions.  */
 
 int
@@ -1779,8 +1779,8 @@
 };
 
 /* Walk the vtable declarations in NAMESPACE.  Whenever one is found
-   for which P returns non-zero, call F with its address.  If any call
-   to F returns a non-zero value, return a non-zero value.  */
+   for which P returns nonzero, call F with its address.  If any call
+   to F returns a nonzero value, return a nonzero value.  */
 
 static int
 walk_vtables_r (namespace, data)
@@ -1800,8 +1800,8 @@
 }
 
 /* Walk the vtable declarations.  Whenever one is found for which P
-   returns non-zero, call F with its address.  If any call to F
-   returns a non-zero value, return a non-zero value.  */
+   returns nonzero, call F with its address.  If any call to F
+   returns a nonzero value, return a nonzero value.  */
 int
 walk_vtables (p, f, data)
      walk_globals_pred p;
@@ -1848,8 +1848,8 @@
 }
 
 /* Walk the global declarations in NAMESPACE.  Whenever one is found
-   for which P returns non-zero, call F with its address.  If any call
-   to F returns a non-zero value, return a non-zero value.  */
+   for which P returns nonzero, call F with its address.  If any call
+   to F returns a nonzero value, return a nonzero value.  */
 
 static int
 walk_globals_r (namespace, data)
@@ -1882,8 +1882,8 @@
 }
 
 /* Walk the global declarations.  Whenever one is found for which P
-   returns non-zero, call F with its address.  If any call to F
-   returns a non-zero value, return a non-zero value.  */
+   returns nonzero, call F with its address.  If any call to F
+   returns a nonzero value, return a nonzero value.  */
 
 int
 walk_globals (p, f, data)
@@ -2559,7 +2559,7 @@
 
 /* The type TYPE is being declared.  If it is a class template, or a
    specialization of a class template, do any processing required and
-   perform error-checking.  If IS_FRIEND is non-zero, this TYPE is
+   perform error-checking.  If IS_FRIEND is nonzero, this TYPE is
    being declared a friend.  B is the binding level at which this TYPE
    should be bound.
 
@@ -5292,7 +5292,7 @@
      int thislevel_only;
 {
   register struct cp_binding_level *level;
   /* Non-zero if, we should look past a template parameter level, even
      if THISLEVEL_ONLY.  */
   int allow_template_parms_p = 1;
 
@@ -5375,7 +5375,7 @@
 		 are in the pseudo-global level created for the
 		 template parameters, rather than the (surrounding)
 		 namespace level.  Thus, we keep going one more level,
-		 even though THISLEVEL_ONLY is non-zero.  */
+		 even though THISLEVEL_ONLY is nonzero.  */
 	      allow_template_parms_p = 0;
 	      continue;
 	    }
@@ -5399,7 +5399,7 @@
    Otherwise return 0.  However, the value can never be 0
    in the cases in which this is used.
 
-   C++: If NAME is non-zero, this is the new name to install.  This is
+   C++: If NAME is nonzero, this is the new name to install.  This is
    done when replacing anonymous tags with real tag names.  */
 
 static tree
@@ -6022,7 +6022,7 @@
    If PREFER_TYPE is -2, we're being called from yylex(). (UGLY)
    Otherwise we prefer non-TYPE_DECLs.
 
-   If NONCLASS is non-zero, we don't look for the NAME in class scope,
+   If NONCLASS is nonzero, we don't look for the NAME in class scope,
    using IDENTIFIER_CLASS_VALUE.  */
 
 static tree
@@ -6425,7 +6425,7 @@
   const char *const name;
   /* The place where the IDENTIFIER_NODE should be stored.  */
   tree *const node;
   /* Non-zero if this is the name of a constructor or destructor.  */
   const int ctor_or_dtor_p;
 } predefined_identifier;
 
@@ -8394,7 +8394,7 @@
 }
 
 /* Returns a pointer to the `atexit' function.  Note that if
-   FLAG_USE_CXA_ATEXIT is non-zero, then this will actually be the new
+   FLAG_USE_CXA_ATEXIT is nonzero, then this will actually be the new
    `__cxa_atexit' function specified in the IA64 C++ ABI.  */
 
 static tree
@@ -11985,7 +11985,7 @@
     }
 }
 
 /* Returns non-zero if T is a local variable.  */
 
 int
 local_variable_p (t)
@@ -12003,7 +12003,7 @@
   return 0;
 }
 
 /* Returns non-zero if T is an automatic local variable or a label.
    (These are the declarations that need to be remapped when the code
    containing them is duplicated.)  */
 
@@ -12253,7 +12253,7 @@
       first parameter is a reference to non-const qualified T.
 
    This function can be used as a predicate. Positive values indicate
-   a copy constructor and non-zero values indicate a copy assignment
+   a copy constructor and nonzero values indicate a copy assignment
    operator.  */
 
 int
@@ -12890,7 +12890,7 @@
 	  && template_class_depth (current_class_type)
 	  && PROCESSING_REAL_TEMPLATE_DECL_P ())
 	{
 	  /* Since GLOBALIZE is non-zero, we are not looking at a
 	     definition of this tag.  Since, in addition, we are currently
 	     processing a (member) template declaration of a template
 	     class, we must be very careful; consider:
@@ -659,7 +659,7 @@
 }
 
-/* If KEEP is non-zero, make a BLOCK node for the next binding level,
+/* If KEEP is nonzero, make a BLOCK node for the next binding level,
    unconditionally.  Otherwise, use the normal logic to decide whether
    or not to create a BLOCK.  */
@@ -688,7 +688,7 @@
 }
 
-/* Returns non-zero if this scope was created to store template
+/* Returns nonzero if this scope was created to store template
    parameters.  */
 
@@ -1740,7 +1740,7 @@
 }
 
-/* Returns non-zero if T is a virtual function table.  */
+/* Returns nonzero if T is a virtual function table.  */
 
 int
@@ -1750,7 +1750,7 @@
 }
 
-/* Returns non-zero if T is a TYPE_DECL for a type with virtual
+/* Returns nonzero if T is a TYPE_DECL for a type with virtual
    functions.  */
 
@@ -5292,7 +5292,7 @@
 {
   register struct cp_binding_level *level;
-  /* Non-zero if, we should look past a template parameter level, even
+  /* Nonzero if, we should look past a template parameter level, even
      if THISLEVEL_ONLY.  */
   int allow_template_parms_p = 1;
@@ -6425,7 +6425,7 @@
   /* The place where the IDENTIFIER_NODE should be stored.  */
   tree *const node;
-  /* Non-zero if this is the name of a constructor or destructor.  */
+  /* Nonzero if this is the name of a constructor or destructor.  */
   const int ctor_or_dtor_p;
 } predefined_identifier;
@@ -11985,7 +11985,7 @@
 }
 
-/* Returns non-zero if T is a local variable.  */
+/* Returns nonzero if T is a local variable.  */
 
 int
@@ -12003,7 +12003,7 @@
 }
 
-/* Returns non-zero if T is an automatic local variable or a label.
+/* Returns nonzero if T is an automatic local variable or a label.
    (These are the declarations that need to be remapped when the code
    containing them is duplicated.)  */
@@ -12890,7 +12890,7 @@
 	  && PROCESSING_REAL_TEMPLATE_DECL_P ())
 	{
-	  /* Since GLOBALIZE is non-zero, we are not looking at a
+	  /* Since GLOBALIZE is nonzero, we are not looking at a
 	     definition of this tag.  Since, in addition, we are currently
 	     processing a (member) template declaration of a template
Index: decl2.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/decl2.c,v
retrieving revision 1.562
diff -u -r1.562 decl2.c
--- decl2.c	19 Sep 2002 16:19:36 -0000	1.562
+++ decl2.c	21 Sep 2002 12:43:19 -0000
@@ -50,10 +50,10 @@
 /* This structure contains information about the initializations
    and/or destructions required for a particular priority level.  */
 typedef struct priority_info_s {
   /* Non-zero if there have been any initializations at this priority
      throughout the translation unit.  */
   int initializations_p;
   /* Non-zero if there have been any destructions at this priority
      throughout the translation unit.  */
   int destructions_p;
 } *priority_info;
@@ -536,7 +536,7 @@
       return error_mark_node;
     }
 
-  /* Deleting ptr to void is undefined behaviour [expr.delete/3].  */
+  /* Deleting ptr to void is undefined behavior [expr.delete/3].  */
   if (TREE_CODE (TREE_TYPE (type)) == VOID_TYPE)
     {
       warning ("deleting `%T' is undefined", type);
@@ -1950,7 +1950,7 @@
 }
 
 /* Here, we only decide whether or not the tinfo node should be
-   emitted with the vtable.  IS_IN_LIBRARY is non-zero iff the
+   emitted with the vtable.  IS_IN_LIBRARY is nonzero iff the
    typeinfo for TYPE should be in the runtime library.  */
 
 void
@@ -2226,7 +2226,7 @@
    initialization and destruction of objects with static storage
    duration.  The function generated takes two parameters of type
    `int': __INITIALIZE_P and __PRIORITY.  If __INITIALIZE_P is
-   non-zero, it performs initializations.  Otherwise, it performs
+   nonzero, it performs initializations.  Otherwise, it performs
    destructions.  It only performs those initializations or
    destructions with the indicated __PRIORITY.  The generated function
    returns no value.  
@@ -2373,7 +2373,7 @@
 }
 
 /* Set up to handle the initialization or destruction of DECL.  If
-   INITP is non-zero, we are initializing the variable.  Otherwise, we
+   INITP is nonzero, we are initializing the variable.  Otherwise, we
    are destroying it.  */
 
 static tree
@@ -3999,7 +3999,7 @@
 }
 
 /* [basic.lookup.koenig] */
 /* A non-zero return value in the functions below indicates an error.  */
 
 struct arg_lookup
 {
@@ -4742,7 +4742,7 @@
    nonterminals. AGGR is the class, union or struct tag. SCOPE is the
    explicit scope used (NULL for no scope resolution). ID is the
    name. DEFN_P is true, if this is a definition of the class and
-   NEW_TYPE_P is set to non-zero, if we push into the scope containing
+   NEW_TYPE_P is set to nonzero, if we push into the scope containing
    the to be defined aggregate.
    
    Return a TYPE_DECL for the type declared by ID in SCOPE.  */
@@ -50,10 +50,10 @@
    and/or destructions required for a particular priority level.  */
 typedef struct priority_info_s {
-  /* Non-zero if there have been any initializations at this priority
+  /* Nonzero if there have been any initializations at this priority
      throughout the translation unit.  */
   int initializations_p;
@@ -50,10 +50,10 @@
      throughout the translation unit.  */
   int initializations_p;
-  /* Non-zero if there have been any destructions at this priority
+  /* Nonzero if there have been any destructions at this priority
      throughout the translation unit.  */
   int destructions_p;
@@ -3999,7 +3999,7 @@
 
 /* [basic.lookup.koenig] */
-/* A non-zero return value in the functions below indicates an error.  */
+/* A nonzero return value in the functions below indicates an error.  */
 
 struct arg_lookup
Index: mangle.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/mangle.c,v
retrieving revision 1.58
diff -u -r1.58 mangle.c
--- mangle.c	14 Sep 2002 12:07:43 -0000	1.58
+++ mangle.c	21 Sep 2002 12:43:26 -0000
@@ -75,7 +75,7 @@
 # define MANGLE_TRACE_TREE(FN, NODE)
 #endif
 
 /* Non-zero if NODE is a class template-id.  We can't rely on
    CLASSTYPE_USE_TEMPLATE here because of tricky bugs in the parser
    that hard to distinguish A<T> from A, where A<T> is the type as
    instantiated outside of the template, and A is the type used
@@ -214,7 +214,7 @@
 #define write_string(STRING)                                          \
   obstack_grow (&G.name_obstack, (STRING), strlen (STRING))
 
 /* Non-zero if NODE1 and NODE2 are both TREE_LIST nodes and have the
    same purpose (context, which may be a type) and value (template
    decl).  See write_template_prefix for more information on what this
    is used for.  */
@@ -230,7 +230,7 @@
 #define write_unsigned_number(NUMBER) \
   write_number ((NUMBER), /*unsigned_p=*/1, 10)
 
 /* If DECL is a template instance, return non-zero and, if
    TEMPLATE_INFO is non-NULL, set *TEMPLATE_INFO to its template info.
    Otherwise return zero.  */
 
@@ -370,7 +370,7 @@
     dump_substitution_candidates ();
 }
 
 /* Helper function for find_substitution.  Returns non-zero if NODE,
    which may be a decl or a CLASS_TYPE, is a template-id with template
    name of substitution_index[INDEX] in the ::std namespace.  */
 
@@ -403,7 +403,7 @@
 	      == subst_identifiers[index]));
 }
 
 /* Helper function for find_substitution.  Returns non-zero if NODE,
    which may be a decl or a CLASS_TYPE, is the template-id
    ::std::identifier<char>, where identifier is
    substitution_index[INDEX].  */
@@ -463,7 +463,7 @@
    candidates for entities appearing earlier in the same mangling
 
    If a substitution is found, write its mangled representation and
-   return non-zero.  If none is found, just return zero.  */
+   return nonzero.  If none is found, just return zero.  */
 
 static int
 find_substitution (node)
@@ -665,7 +665,7 @@
 	  ::= <nested-name>
 	  ::= <local-name>  
 
-   If IGNORE_LOCAL_SCOPE is non-zero, this production of <name> is
+   If IGNORE_LOCAL_SCOPE is nonzero, this production of <name> is
    called from <local-name>, which mangles the enclosing scope
    elsewhere and then uses this function to mangle just the part
    underneath the function scope.  So don't use the <local-name>
@@ -1341,7 +1341,7 @@
 write_type (type)
      tree type;
 {
   /* This gets set to non-zero if TYPE turns out to be a (possibly
      CV-qualified) builtin type.  */
   int is_builtin_type = 0;
 
@@ -1645,7 +1645,7 @@
 }
 
 /* Non-terminal <bare-function-type>.  TYPE is a FUNCTION_TYPE or
-   METHOD_TYPE.  If INCLUDE_RETURN_TYPE is non-zero, the return value
+   METHOD_TYPE.  If INCLUDE_RETURN_TYPE is nonzero, the return value
    is mangled before the parameter types.  If non-NULL, DECL is
    FUNCTION_DECL for the function whose type is being emitted.
 
@@ -1670,7 +1670,7 @@
 }
 
 /* Write the mangled representation of a method parameter list of
-   types given in PARM_TYPES.  If METHOD_P is non-zero, the function is 
+   types given in PARM_TYPES.  If METHOD_P is nonzero, the function is
    considered a non-static method, and the this parameter is omitted.
    If non-NULL, DECL is the FUNCTION_DECL for the function whose
    parameters are being emitted.  */
@@ -75,7 +75,7 @@
 #endif
 
-/* Non-zero if NODE is a class template-id.  We can't rely on
+/* Nonzero if NODE is a class template-id.  We can't rely on
    CLASSTYPE_USE_TEMPLATE here because of tricky bugs in the parser
    that hard to distinguish A<T> from A, where A<T> is the type as
@@ -214,7 +214,7 @@
   obstack_grow (&G.name_obstack, (STRING), strlen (STRING))
 
-/* Non-zero if NODE1 and NODE2 are both TREE_LIST nodes and have the
+/* Nonzero if NODE1 and NODE2 are both TREE_LIST nodes and have the
    same purpose (context, which may be a type) and value (template
    decl).  See write_template_prefix for more information on what this
@@ -230,7 +230,7 @@
   write_number ((NUMBER), /*unsigned_p=*/1, 10)
 
-/* If DECL is a template instance, return non-zero and, if
+/* If DECL is a template instance, return nonzero and, if
    TEMPLATE_INFO is non-NULL, set *TEMPLATE_INFO to its template info.
    Otherwise return zero.  */
@@ -370,7 +370,7 @@
 }
 
-/* Helper function for find_substitution.  Returns non-zero if NODE,
+/* Helper function for find_substitution.  Returns nonzero if NODE,
    which may be a decl or a CLASS_TYPE, is a template-id with template
    name of substitution_index[INDEX] in the ::std namespace.  */
@@ -403,7 +403,7 @@
 }
 
-/* Helper function for find_substitution.  Returns non-zero if NODE,
+/* Helper function for find_substitution.  Returns nonzero if NODE,
    which may be a decl or a CLASS_TYPE, is the template-id
    ::std::identifier<char>, where identifier is
@@ -1341,7 +1341,7 @@
      tree type;
 {
-  /* This gets set to non-zero if TYPE turns out to be a (possibly
+  /* This gets set to nonzero if TYPE turns out to be a (possibly
      CV-qualified) builtin type.  */
   int is_builtin_type = 0;
Index: optimize.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/optimize.c,v
retrieving revision 1.83
diff -u -r1.83 optimize.c
--- optimize.c	14 Sep 2002 12:07:43 -0000	1.83
+++ optimize.c	21 Sep 2002 12:43:27 -0000
@@ -93,9 +93,9 @@
   return setjmp_call_p (*tp) ? *tp : NULL_TREE;
 }
 
 /* Returns non-zero if FN calls `setjmp' or some other function that
    can return more than once.  This function is conservative; it may
-   occasionally return a non-zero value even when FN does not actually
+   occasionally return a nonzero value even when FN does not actually
    call `setjmp'.  */
 
 int
@@ -133,7 +133,7 @@
 }
 
 /* FN is a function that has a complete body.  Clone the body as
-   necessary.  Returns non-zero if there's no longer any need to
+   necessary.  Returns nonzero if there's no longer any need to
    process the main body.  */
 
 int
@@ -93,9 +93,9 @@
 }
 
-/* Returns non-zero if FN calls `setjmp' or some other function that
+/* Returns nonzero if FN calls `setjmp' or some other function that
    can return more than once.  This function is conservative; it may
Index: pt.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/pt.c,v
retrieving revision 1.616
diff -u -r1.616 pt.c
--- pt.c	16 Sep 2002 19:57:31 -0000	1.616
+++ pt.c	21 Sep 2002 12:43:36 -0000
@@ -402,7 +402,7 @@
     }
 }
 
 /* Returns non-zero iff T is a member template function.  We must be
    careful as in
 
      template <class T> class C { void f(); }
@@ -439,7 +439,7 @@
 }
 
 #if 0 /* UNUSED */
 /* Returns non-zero iff T is a member template class.  See
    is_member_template for a description of what precisely constitutes
    a member template.  */
 
@@ -647,7 +647,7 @@
   template_header_count = 0;
 }
 
 /* We've just seen a template header.  If SPECIALIZATION is non-zero,
    it was of the form template <>.  */
 
 static void 
@@ -744,7 +744,7 @@
   return (tree) htab_find (local_specializations, tmpl);
 }
 
 /* Returns non-zero iff DECL is a specialization of TMPL.  */
 
 int
 is_specialization_of (decl, tmpl)
@@ -947,7 +947,7 @@
    NULL_TREE if none is available.  In that case, the functions in
    TEMPLATE_ID are non-members.
 
-   If NEED_MEMBER_TEMPLATE is non-zero the function is known to be a
+   If NEED_MEMBER_TEMPLATE is nonzero the function is known to be a
    specialization of a member template.
 
    The template args (those explicitly specified and those deduced)
@@ -2132,12 +2132,12 @@
   int current_arg;
 
   /* An array whose size is the number of template parameters.  The
-     elements are non-zero if the parameter has been used in any one
+     elements are nonzero if the parameter has been used in any one
      of the arguments processed so far.  */
   int* parms;
 
   /* An array whose size is the number of template arguments.  The
-     elements are non-zero if the argument makes use of template
+     elements are nonzero if the argument makes use of template
      parameters of this level.  */
   int* arg_uses_template_parms;
 };
@@ -2355,8 +2355,8 @@
 
 /* Check that a template declaration's use of default arguments is not
    invalid.  Here, PARMS are the template parameters.  IS_PRIMARY is
-   non-zero if DECL is the thing declared by a primary template.
-   IS_PARTIAL is non-zero if DECL is a partial specialization.  */
+   nonzero if DECL is the thing declared by a primary template.
+   IS_PARTIAL is nonzero if DECL is a partial specialization.  */
 
 static void
 check_default_tmpl_args (decl, parms, is_primary, is_partial)
@@ -2503,7 +2503,7 @@
 /* Worker for push_template_decl_real, called via
    for_each_template_parm.  DATA is really an int, indicating the
    level of the parameters we are interested in.  If T is a template
-   parameter of that level, return non-zero.  */
+   parameter of that level, return nonzero.  */
 
 static int
 template_parm_this_level_p (t, data)
@@ -2525,7 +2525,7 @@
    previously existing one, if appropriate.  Returns the DECL, or an
    equivalent one, if it is replaced via a call to duplicate_decls.  
 
-   If IS_FRIEND is non-zero, DECL is a friend declaration.  */
+   If IS_FRIEND is nonzero, DECL is a friend declaration.  */
 
 tree
 push_template_decl_real (decl, is_friend)
@@ -3512,7 +3512,7 @@
    messages are issued even if COMPLAIN is zero; for instance, if a
    template argument is composed from a local class.
 
-   If REQUIRE_ALL_ARGUMENTS is non-zero, all arguments must be
+   If REQUIRE_ALL_ARGUMENTS is nonzero, all arguments must be
    provided in ARGLIST, or else trailing parameters must have default
    values.  If REQUIRE_ALL_ARGUMENTS is zero, we will attempt argument
    deduction for any unspecified trailing arguments.  */
@@ -3885,7 +3885,7 @@
    IN_DECL, if non-NULL, is the template declaration we are trying to
    instantiate.  
 
-   If ENTERING_SCOPE is non-zero, we are about to enter the scope of
+   If ENTERING_SCOPE is nonzero, we are about to enter the scope of
    the class we are looking up.
    
    Issue error and warning messages under control of COMPLAIN.
@@ -4480,9 +4480,9 @@
 /* For each TEMPLATE_TYPE_PARM, TEMPLATE_TEMPLATE_PARM, 
    BOUND_TEMPLATE_TEMPLATE_PARM or TEMPLATE_PARM_INDEX in T, 
    call FN with the parameter and the DATA.
-   If FN returns non-zero, the iteration is terminated, and
+   If FN returns nonzero, the iteration is terminated, and
    for_each_template_parm returns 1.  Otherwise, the iteration
-   continues.  If FN never returns a non-zero value, the value
+   continues.  If FN never returns a nonzero value, the value
    returned by for_each_template_parm is 0.  If FN is NULL, it is
    considered to be the function which always returns 1.  */
 
@@ -5546,7 +5546,7 @@
 /* Substitute the ARGS into the indicated aggregate (or enumeration)
    type T.  If T is not an aggregate or enumeration type, it is
    handled as if by tsubst.  IN_DECL is as for tsubst.  If
-   ENTERING_SCOPE is non-zero, T is the context for a template which
+   ENTERING_SCOPE is nonzero, T is the context for a template which
    we are presently tsubst'ing.  Return the substituted value.  */
 
 static tree
@@ -8553,7 +8553,7 @@
 
 /* Decide whether ARG can be unified with PARM, considering only the
    cv-qualifiers of each type, given STRICT as documented for unify.
-   Returns non-zero iff the unification is OK on that basis.*/
+   Returns nonzero iff the unification is OK on that basis.*/
 
 static int
 check_cv_quals_for_unify (strict, arg, parm)
@@ -9653,7 +9653,7 @@
 
 /* Perform an explicit instantiation of template class T.  STORAGE, if
    non-null, is the RID for extern, inline or static.  COMPLAIN is
-   non-zero if this is called from the parser, zero if called recursively,
+   nonzero if this is called from the parser, zero if called recursively,
    since the standard is unclear (as detailed below).  */
  
 void
@@ -9897,7 +9897,7 @@
 }
 
 /* Produce the definition of D, a _DECL generated from a template.  If
-   DEFER_OK is non-zero, then we don't have to actually do the
+   DEFER_OK is nonzero, then we don't have to actually do the
    instantiation now; we just have to do it sometime.  */
 
 tree
@@ -10458,7 +10458,7 @@
 }
 
 /* [temp.param] Check that template non-type parm TYPE is of an allowable
-   type. Return zero for ok, non-zero for disallowed. Issue error and
+   type. Return zero for ok, nonzero for disallowed. Issue error and
    warning messages under control of COMPLAIN.  */
 
 static int
@@ -402,7 +402,7 @@
 }
 
-/* Returns non-zero iff T is a member template function.  We must be
+/* Returns nonzero iff T is a member template function.  We must be
    careful as in
 
@@ -439,7 +439,7 @@
 
 #if 0 /* UNUSED */
-/* Returns non-zero iff T is a member template class.  See
+/* Returns nonzero iff T is a member template class.  See
    is_member_template for a description of what precisely constitutes
    a member template.  */
@@ -647,7 +647,7 @@
 }
 
-/* We've just seen a template header.  If SPECIALIZATION is non-zero,
+/* We've just seen a template header.  If SPECIALIZATION is nonzero,
    it was of the form template <>.  */
 
@@ -744,7 +744,7 @@
 }
 
-/* Returns non-zero iff DECL is a specialization of TMPL.  */
+/* Returns nonzero iff DECL is a specialization of TMPL.  */
 
 int
Index: rtti.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/rtti.c,v
retrieving revision 1.141
diff -u -r1.141 rtti.c
--- rtti.c	14 Sep 2002 12:07:44 -0000	1.141
+++ rtti.c	21 Sep 2002 12:43:38 -0000
@@ -697,7 +697,7 @@
   return flags;
 }
 
 /* Return non-zero, if the pointer chain TYPE ends at an incomplete type, or
    contains a pointer to member of an incomplete class.  */
 
 static int
@@ -977,7 +977,7 @@
   return init;  
 }
 
 /* Returns non-zero if the typeinfo for type should be placed in 
    the runtime library.  */
 
 static int
@@ -1006,7 +1006,7 @@
 }
 
 /* Generate the initializer for the type info describing
-   TYPE. VAR_DESC is a . NON_PUBLIC_P is set non-zero, if the VAR_DECL
+   TYPE. VAR_DESC is a . NON_PUBLIC_P is set nonzero, if the VAR_DECL
    should not be exported from this object file.  This should only be
    called at the end of translation, when we know that no further
    types will be completed.  */
@@ -1407,7 +1407,7 @@
     }
 }
 
 /* Return non-zero, iff T is a type_info variable which has not had a
    definition emitted for it.  */
 
 int
@@ -697,7 +697,7 @@
 }
 
-/* Return non-zero, if the pointer chain TYPE ends at an incomplete type, or
+/* Return nonzero, if the pointer chain TYPE ends at an incomplete type, or
    contains a pointer to member of an incomplete class.  */
 
@@ -977,7 +977,7 @@
 }
 
-/* Returns non-zero if the typeinfo for type should be placed in 
+/* Returns nonzero if the typeinfo for type should be placed in
    the runtime library.  */
 
@@ -1407,7 +1407,7 @@
 }
 
-/* Return non-zero, iff T is a type_info variable which has not had a
+/* Return nonzero, iff T is a type_info variable which has not had a
    definition emitted for it.  */
 
Index: search.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/search.c,v
retrieving revision 1.237
diff -u -r1.237 search.c
--- search.c	16 Sep 2002 19:09:04 -0000	1.237
+++ search.c	21 Sep 2002 12:43:40 -0000
@@ -577,7 +577,7 @@
   return current_class_type;
 }
 
 /* Returns non-zero if we are currently in a function scope.  Note
    that this function returns zero if we are within a local class, but
    not within a member function body of the local class.  */
 
@@ -862,7 +862,7 @@
   return NULL_TREE;
 }
 
 /* Returns non-zero if it is OK to access DECL through an object
    indiated by BINFO in the context of DERIVED.  */
 
 static int
@@ -925,7 +925,7 @@
   return 1;
 }
 
 /* Returns non-zero if SCOPE is a friend of a type which would be able
    to access DECL through the object indicated by BINFO.  */
 
 static int
@@ -1014,7 +1014,7 @@
 }
 
 /* DECL is a declaration from a base class of TYPE, which was the
-   class used to name DECL.  Return non-zero if, in the current
+   class used to name DECL.  Return nonzero if, in the current
    context, DECL is accessible.  If TYPE is actually a BINFO node,
    then we can tell in what context the access is occurring by looking
    at the most derived class along the path indicated by BINFO.  */
@@ -1028,7 +1028,7 @@
   tree binfo;
   tree t;
 
   /* Non-zero if it's OK to access DECL if it has protected
      accessibility in TYPE.  */
   int protected_ok = 0;
 
@@ -1146,15 +1146,15 @@
   /* If non-NULL, the lookup was ambiguous, and this is a list of the
      candidates.  */
   tree ambiguous;
   /* If non-zero, we are looking for types, not data members.  */
   int want_type;
   /* If non-zero, RVAL was found by looking through a dependent base.  */
   int from_dep_base_p;
   /* If something went wrong, a message indicating what.  */
   const char *errstr;
 };
 
 /* Returns non-zero if BINFO is not hidden by the value found by the
    lookup so far.  If BINFO is hidden, then there's no need to look in
    it.  DATA is really a struct lookup_field_info.  Called from
    lookup_field via breadth_first_search.  */
@@ -1185,7 +1185,7 @@
    
      template <typename T> struct S { S* sp; }
 
-   Returns non-zero if DECL is such a declaration in a class TYPE.  */
+   Returns nonzero if DECL is such a declaration in a class TYPE.  */
 
 static int
 template_self_reference_p (type, decl)
@@ -1692,7 +1692,7 @@
    returned and the walk is terminated.  At each node, FN is passed a
    BINFO indicating the path from the curently visited base-class to
    TYPE.  Before each base-class is walked QFN is called.  If the
-   value returned is non-zero, the base-class is walked; otherwise it
+   value returned is nonzero, the base-class is walked; otherwise it
    is not.  If QFN is NULL, it is treated as a function which always
    returns 1.  Both FN and QFN are passed the DATA whenever they are
    called.  */
@@ -1929,7 +1929,7 @@
    virtual functions in TYPE's hierarchy which FNDECL overrides.
    We do not look in TYPE itself, only its bases.
    
-   Returns non-zero, if we find any. Set FNDECL's DECL_VIRTUAL_P, if we
+   Returns nonzero, if we find any. Set FNDECL's DECL_VIRTUAL_P, if we
    find that it overrides anything.
    
    We check that every function which is overridden, is correctly
@@ -577,7 +577,7 @@
 }
 
-/* Returns non-zero if we are currently in a function scope.  Note
+/* Returns nonzero if we are currently in a function scope.  Note
    that this function returns zero if we are within a local class, but
    not within a member function body of the local class.  */
@@ -862,7 +862,7 @@
 }
 
-/* Returns non-zero if it is OK to access DECL through an object
+/* Returns nonzero if it is OK to access DECL through an object
    indiated by BINFO in the context of DERIVED.  */
 
@@ -925,7 +925,7 @@
 }
 
-/* Returns non-zero if SCOPE is a friend of a type which would be able
+/* Returns nonzero if SCOPE is a friend of a type which would be able
    to access DECL through the object indicated by BINFO.  */
 
@@ -1028,7 +1028,7 @@
   tree t;
 
-  /* Non-zero if it's OK to access DECL if it has protected
+  /* Nonzero if it's OK to access DECL if it has protected
      accessibility in TYPE.  */
   int protected_ok = 0;
@@ -1146,15 +1146,15 @@
      candidates.  */
   tree ambiguous;
-  /* If non-zero, we are looking for types, not data members.  */
+  /* If nonzero, we are looking for types, not data members.  */
   int want_type;
@@ -1146,15 +1146,15 @@
   int want_type;
-  /* If non-zero, RVAL was found by looking through a dependent base.  */
+  /* If nonzero, RVAL was found by looking through a dependent base.  */
   int from_dep_base_p;
   /* If something went wrong, a message indicating what.  */
@@ -1146,15 +1146,15 @@
 };
 
-/* Returns non-zero if BINFO is not hidden by the value found by the
+/* Returns nonzero if BINFO is not hidden by the value found by the
    lookup so far.  If BINFO is hidden, then there's no need to look in
    it.  DATA is really a struct lookup_field_info.  Called from
Index: semantics.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/semantics.c,v
retrieving revision 1.277
diff -u -r1.277 semantics.c
--- semantics.c	16 Sep 2002 14:34:00 -0000	1.277
+++ semantics.c	21 Sep 2002 12:43:42 -0000
@@ -79,7 +79,7 @@
       (SUBSTMT) = (COND);				\
   } while (0)
 
 /* Returns non-zero if the current statement is a full expression,
    i.e. temporaries created during that statement should be destroyed
    at the end of the statement.  */
 
@@ -801,7 +801,7 @@
   RECHAIN_STMTS (handler, HANDLER_BODY (handler));
 }
 
 /* Begin a compound-statement.  If HAS_NO_SCOPE is non-zero, the
    compound-statement does not define a scope.  Returns a new
    COMPOUND_STMT if appropriate.  */
 
@@ -840,7 +840,7 @@
 }
 
 /* Finish a compound-statement, which may be given by COMPOUND_STMT.
-   If HAS_NO_SCOPE is non-zero, the compound statement does not define
+   If HAS_NO_SCOPE is nonzero, the compound statement does not define
    a scope.  */
 
 tree
@@ -1572,7 +1572,7 @@
 }
 
 /* Begin a function definition declared with DECL_SPECS, ATTRIBUTES,
-   and DECLARATOR.  Returns non-zero if the function-declaration is
+   and DECLARATOR.  Returns nonzero if the function-declaration is
    valid.  */
 
 int
@@ -1696,7 +1696,7 @@
 }
 
 /* Finish a parameter list, indicated by PARMS.  If ELLIPSIS is
-   non-zero, the parameter list was terminated by a `...'.  */
+   nonzero, the parameter list was terminated by a `...'.  */
 
 tree
 finish_parmlist (parms, ellipsis)
@@ -2022,7 +2022,7 @@
 
 /* Finish processing a template-id (which names a type) of the form
    NAME < ARGS >.  Return the TYPE_DECL for the type named by the
-   template-id.  If ENTERING_SCOPE is non-zero we are about to enter
+   template-id.  If ENTERING_SCOPE is nonzero we are about to enter
    the scope of template-id indicated.  */
 
 tree
@@ -79,7 +79,7 @@
   } while (0)
 
-/* Returns non-zero if the current statement is a full expression,
+/* Returns nonzero if the current statement is a full expression,
    i.e. temporaries created during that statement should be destroyed
    at the end of the statement.  */
@@ -801,7 +801,7 @@
 }
 
-/* Begin a compound-statement.  If HAS_NO_SCOPE is non-zero, the
+/* Begin a compound-statement.  If HAS_NO_SCOPE is nonzero, the
    compound-statement does not define a scope.  Returns a new
    COMPOUND_STMT if appropriate.  */
Index: tree.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/tree.c,v
retrieving revision 1.300
diff -u -r1.300 tree.c
--- tree.c	16 Sep 2002 19:09:03 -0000	1.300
+++ tree.c	21 Sep 2002 12:43:45 -0000
@@ -57,7 +57,7 @@
 
 /* If REF is an lvalue, returns the kind of lvalue that REF is.
    Otherwise, returns clk_none.  If TREAT_CLASS_RVALUES_AS_LVALUES is
-   non-zero, rvalues of class type are considered lvalues.  */
+   nonzero, rvalues of class type are considered lvalues.  */
 
 static cp_lvalue_kind
 lvalue_p_1 (ref, treat_class_rvalues_as_lvalues, allow_cast_as_lvalue)
@@ -1092,7 +1092,7 @@
   return IS_AGGR_TYPE (t1) && IS_AGGR_TYPE (t2);
 }
 
 /* Returns non-zero if CODE is the code for a statement.  */
 
 int
 cp_statement_code_p (code)
@@ -2362,7 +2362,7 @@
   return var;
 }
 
 /* Record that we're about to start inlining FN, and return non-zero if
    that's OK.  Used for lang_hooks.tree_inlining.start_inlining.  */
 
 int
@@ -2549,7 +2549,7 @@
 	  || TREE_CODE (node) == SCOPE_REF);
 }
 
 /* Returns non-zero if TYPE is a character type, including wchar_t.  */
 
 int
 char_type_p (type)
@@ -1092,7 +1092,7 @@
 }
 
-/* Returns non-zero if CODE is the code for a statement.  */
+/* Returns nonzero if CODE is the code for a statement.  */
 
 int
@@ -2362,7 +2362,7 @@
 }
 
-/* Record that we're about to start inlining FN, and return non-zero if
+/* Record that we're about to start inlining FN, and return nonzero if
    that's OK.  Used for lang_hooks.tree_inlining.start_inlining.  */
 
@@ -2549,7 +2549,7 @@
 }
 
-/* Returns non-zero if TYPE is a character type, including wchar_t.  */
+/* Returns nonzero if TYPE is a character type, including wchar_t.  */
 
 int
Index: typeck.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/cp/typeck.c,v
retrieving revision 1.428
diff -u -r1.428 typeck.c
--- typeck.c	16 Sep 2002 14:34:00 -0000	1.428
+++ typeck.c	21 Sep 2002 12:43:50 -0000
@@ -5580,7 +5580,7 @@
    as a value in expressions.  TYPE is the POINTER to METHOD_TYPE we
    want to be.
 
-   If FORCE is non-zero, then force this conversion, even if
+   If FORCE is nonzero, then force this conversion, even if
    we would rather not do it.  Usually set when using an explicit
    cast.
 
@@ -5895,7 +5895,7 @@
 }
 
 /* Convert RHS to be of type TYPE.
-   If EXP is non-zero, it is the target of the initialization.
+   If EXP is nonzero, it is the target of the initialization.
    ERRTYPE is a string to use in error messages.
 
    Two major differences between the behavior of
@@ -6298,9 +6298,9 @@
 }
 
 
 /* Returns non-zero if the pointer-type FROM can be converted to the
    pointer-type TO via a qualification conversion.  If CONSTP is -1,
-   then we return non-zero if the pointers are similar, and the
+   then we return nonzero if the pointers are similar, and the
    cv-qualification signature of FROM is a proper subset of that of TO.
 
    If CONSTP is positive, then all outer pointers have been
@@ -6464,7 +6464,7 @@
   return TYPE_QUALS (type);
 }
 
 /* Returns non-zero if the TYPE contains a mutable member */
 
 int
 cp_has_mutable_p (type)
@@ -6537,7 +6537,7 @@
   *t2 = cp_build_qualified_type (*t2, quals2);
 }
 
 /* Returns non-zero if casting from TYPE1 to TYPE2 casts away
    constness.  */
 
 static int
@@ -6298,9 +6298,9 @@
 
 
-/* Returns non-zero if the pointer-type FROM can be converted to the
+/* Returns nonzero if the pointer-type FROM can be converted to the
    pointer-type TO via a qualification conversion.  If CONSTP is -1,
@@ -6464,7 +6464,7 @@
 }
 
-/* Returns non-zero if the TYPE contains a mutable member */
+/* Returns nonzero if the TYPE contains a mutable member */
 
 int
@@ -6537,7 +6537,7 @@
 }
 
-/* Returns non-zero if casting from TYPE1 to TYPE2 casts away
+/* Returns nonzero if casting from TYPE1 to TYPE2 casts away
    constness.  */
 


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]